<?php

/*
Plugin Name: Newsletters - WooCommerce Subscribers
Plugin URI: http://tribulant.com/extensions/view/42/woocommerce-subscribers
Description: Capture email subscribers from WooCommerce plugin to the Newsletter plugin
Author: Tribulant Software
Version: 1.0
Author URI: http://tribulant.com
Text Domain: newsletters-woocommerce
Domain Path: /languages
*/

if (!defined('DS')) { define('DS', DIRECTORY_SEPARATOR); }
if (!defined('NEWSLETTERS_EXTENSION_URL')) { define('NEWSLETTERS_EXTENSION_URL', "http://tribulant.com/extensions/"); }

if (!class_exists('newsletters_woocommerce')) {
	$path = dirname(dirname(__FILE__)) . DS . 'wp-mailinglist' . DS . 'wp-mailinglist.php';
	$path2 = dirname(dirname(__FILE__)) . DS . 'newsletters-lite' . DS . 'wp-mailinglist.php';
	
	if (file_exists($path)) {
		require_once($path);
	} elseif (file_exists($path2)) {
		require_once($path2);
	} elseif (defined('NEWSLETTERS_NAME')) {
		$path = dirname(dirname(__FILE__)) . DS . NEWSLETTERS_NAME . DS . 'wp-mailinglist.php';
		if (file_exists($path)) {
			require_once($path);
		}
	}
	
	if (class_exists('wpMailPlugin')) {
		class newsletters_woocommerce extends wpMailPlugin {
			
			function newsletters_woocommerce() {
				$this -> sections = (object) $this -> sections;
				$this -> extension_name = basename(dirname(__FILE__));
				$this -> extension_path = plugin_basename(__FILE__);
				$this -> version = '1.0';
				
				$path1 = dirname(dirname(__FILE__)) . DS . 'wp-mailinglist' . DS . 'wp-mailinglist.php';
				$path2 = dirname(dirname(__FILE__)) . DS . 'newsletters-lite' . DS . 'wp-mailinglist.php';
				
				if (file_exists($path1)) {
					$this -> parent_path = plugin_basename('wp-mailinglist' . DS . 'wp-mailinglist.php');
				} elseif (file_exists($path2)) {
					$this -> parent_path = plugin_basename('newsletters-lite' . DS . 'wp-mailinglist.php');
				} elseif (defined('NEWSLETTERS_NAME') && file_exists(dirname(dirname(__FILE__)) . DS . NEWSLETTERS_NAME . DS . 'wp-mailinglist.php')) {
					$this -> parent_path = plugin_basename(NEWSLETTERS_NAME . DS . 'wp-mailinglist.php');
				}
			}
			
			function activation_hook() {
				require_once ABSPATH . 'wp-admin' . DS . 'admin-functions.php';
				$path = 'woocommerce' . DS . 'woocommerce.php';
				
				if (!is_plugin_active(plugin_basename($path)) || 
					!is_plugin_active(plugin_basename($this -> parent_path))) {
					_e('You must have the Newsletter plugin and WooCommerce plugin installed and activated in order to use this.', $this -> extension_name);
					exit(); die();
				} else {		
					$plugin_data = get_plugin_data(WP_PLUGIN_DIR . DS . $path);
					$plugin_version = $plugin_data['Version'];
					$plugin_data2 = get_plugin_data(WP_PLUGIN_DIR . DS . $this -> parent_path);
					$plugin_version2 = $plugin_data2['Version'];
					$woocommerce_required = '2.1';
					$newsletters_required = '4.1';
					
					$versiongood = false;
					if (version_compare($plugin_version, $checkout_required) >= 0 && 
						version_compare($plugin_version2, $newsletters_required) >= 0) {
						$versiongood = true;	
					}
					
					if ($versiongood == true) {
						$this -> add_option('newsletters_woocommerce_checkbox', 1);
						$this -> add_option('newsletters_woocommerce_checkboxautocheck', 1);
						$this -> add_option('newsletters_woocommerce_checkboxlabel', __('Subscribe me to your newsletter'));
					} else {
						echo sprintf(__('The %s extension requires the WooCommerce plugin %s and Newsletter plugin %s at least.', $this -> extension_name), 'WooCommerce Subscribers', $woocommerce_required, $newsletters_required);
						exit(); die();	
					}
				}
				
				return true;
			}
			
			function init_textdomain() {
				if (function_exists('load_plugin_textdomain')) {			
					load_plugin_textdomain($this -> extension_name, false, $this -> extension_name . DS . 'languages' . DS);
				}
			}
			
			function after_plugin_row($plugin_name = null) {		
		        $key = $this -> get_option('serialkey');
		        $update = $this -> vendor('update');
		        $version_info = $update -> get_version_info();
		    }
			
			function display_changelog() {  
				if (!empty($_GET['plugin']) && $_GET['plugin'] == $this -> extension_name) { 		 
			    	require_once dirname(__FILE__) . DS . 'vendors' . DS . 'class.update.php';
					$update = new newsletters_woocommerce_update();
			    	$changelog = $update -> get_changelog();
			    	
			    	echo '<div style="font-family:Arial, Helvetica, sans-serif; font-size:13px;">';
			    	echo $changelog;
			    	echo '</div>';
			    	
			    	exit();
			    }
		    }
			
			function has_update($cache = true) {
				require_once dirname(__FILE__) . DS . 'vendors' . DS . 'class.update.php';
				$update = new newsletters_woocommerce_update();
		        $version_info = $update -> get_version_info($cache);
		        return version_compare($this -> version, $version_info["version"], '<');
		    }
			
			function check_update($option, $cache = true) {
				require_once dirname(__FILE__) . DS . 'vendors' . DS . 'class.update.php';
				$update = new newsletters_woocommerce_update();
		        $version_info = $update -> get_version_info($cache);
		
		        if (!$version_info) { return $option; }
		
		        $plugin_path = $this -> extension_name . '/woocommerce.php';
		        
		        if(empty($option -> response[$plugin_path])) {
					$option -> response[$plugin_path] = new stdClass();
		        }
		
		        //Empty response means that the key is invalid. Do not queue for upgrade
		        if(!$version_info["is_valid_key"] || version_compare($this -> version, $version_info["version"], '>=')){
		            unset($option -> response[$plugin_path]);
		        } else {
		            $option -> response[$plugin_path] -> url = "http://tribulant.com";
		            $option -> response[$plugin_path] -> slug = $this -> extension_name;
		            $option -> response[$plugin_path] -> package = $version_info['url'];
		            $option -> response[$plugin_path] -> new_version = $version_info["version"];
		            $option -> response[$plugin_path] -> id = "0";
		        }
		
		        return $option;
		    }
			
			function metaboxes_extensions_settings($page = null) {
				add_meta_box('newsletters_woocommerce', '<img src="' . plugins_url() . '/' . $this -> extension_name . '/images/icon-16.png" /> ' . __('WooCommerce Subscribers', $this -> extension_name), array($this, 'extensions_settings'), $page, 'normal', 'core');
			}
			
			function extensions_settings() {
				$this -> render('views' . DS . 'settings', false, true, false, 'newsletters_woocommerce');
			}
			
			function contacts_before_register_button($order_id = null, $errors = null) {
				$guestcheckout = $this -> get_option('guestcheckout');
				
				if (empty($guestcheckout) || $guestcheckout == "N") {
					$this -> subscribe_checkbox('contacts', $errors);
				}
			}
			
			function shipping_after_global($order_id = null, $errors = null) {
				global $Order;
				$guestcheckout = $this -> get_option('guestcheckout');
				
				if ($guestcheckout == "Y" && $Order -> do_shipping($order_id)) {
					$this -> subscribe_checkbox('shipping', $errors);
				}
			}
			
			function billing_after_global($order_id = null, $errors = null) {
				global $Order;
				$guestcheckout = $this -> get_option('guestcheckout');
				
				if ($guestcheckout == "Y" && !$Order -> do_shipping($order_id)) {
					$this -> subscribe_checkbox('billing', $errors);
				}
			}
			
			function subscribe_checkbox($place = 'contacts', $errors = null) {
				if ($this -> get_option('newsletters_checkbox') == "Y") {
					$this -> render('views' . DS . 'subscribe-checkbox', array('errors' => $errors), true, false, 'newsletters_woocommerce');
				}
			}
			
			function extensions_list($extensions = array()) {
				$extensions['newsletters_woocommerce'] = array(
					'name'			=>	__('WooCommerce Subscribers', $this -> extension_name),
					'link'			=>	"http://tribulant.com/extensions/view/42/woocommerce-subscribers",
					'image'			=>	plugins_url() . '/' . $this -> extension_name . '/images/icon.png',
					'description'	=>	sprintf(__("Capture email subscribers from the WooCommerce plugin to the %sNewsletter plugin%s.", $this -> extension_name), '<a href="http://tribulant.com/plugins/view/1/wordpress-newsletter-plugin" target="_blank">', '</a>'),
					'slug'			=>	'newsletters_woocommerce',
					'plugin_name'	=>	$this -> extension_name,
					'plugin_file'	=>	'woocommerce.php',
					'settings'		=>	'?page=' . $this -> sections -> extensions_settings . '#newsletters_woocommerce',
				);
				
				$titles = array();
				foreach ($extensions as $extension) {
					$titles[] = $extension['name'];
				}
				
				array_multisort($titles, SORT_ASC, $extensions);
				return $extensions;
			}
			
			function newsletters_extensions_settings_saved($post = null) {
				if (empty($_POST['newsletters_woocommerce_checkbox'])) {
					$this -> delete_option('newsletters_woocommerce_checkbox');
				}
				
				if (empty($_POST['newsletters_woocommerce_checkboxautocheck'])) {
					$this -> delete_option('newsletters_woocommerce_checkboxautocheck');
				}
			
				return;
			}
			
			function plugin_action_links($actions = null, $plugin_file = null, $plugin_data = null, $context = null) {
				$this_plugin = plugin_basename(__FILE__);
				
				if (!empty($plugin_file) && $plugin_file == $this_plugin) {
					$actions[] = '<a href="' . wp_nonce_url('admin.php?page=' . $this -> sections -> extensions_settings) . '#newsletters_woocommerce">' . __('Settings', $this -> extension_name) . '</a>';
				}
				
				return $actions;
			}
			
			function subscribe($data = null) {
				if (class_exists('wpMail')) {
					$wpMail = new wpMail();
					global $Subscriber;
					$Subscriber -> optin($data, false, false, true);
					return $Subscriber -> errors;
				}
			}
			
			function woo_checkout_after_customer_details() {
				$newsletters_woocommerce_checkbox = $this -> get_option('newsletters_woocommerce_checkbox');
				if (!empty($newsletters_woocommerce_checkbox)) {
					$this -> render('views' . DS . 'subscribe', array('errors' => $errors), true, false, 'newsletters_woocommerce');
				}
			}
			
			function woo_checkout_validation($posted = null) {
				if (!empty($_POST['newsletters'])) {
					$newsletters_woocommerce_mailinglists = $this -> get_option('newsletters_woocommerce_mailinglists');
					
					$data = array(
						'email'				=>	$posted['billing_email'],
						'list_id'			=>	$newsletters_woocommerce_mailinglists,
						'mailinglists'		=>	$newsletters_woocommerce_mailinglists,
					);
					
					$newsletters_woocommerce_errors = $this -> subscribe($data);
					
					if (!empty($newsletters_woocommerce_errors)) {
						foreach ($newsletters_woocommerce_errors as $error) {
							wc_add_notice($error, 'error');
						}
					}
				}
			}
		}
		
		$plugin = plugin_basename(__FILE__);
		$newsletters_woocommerce = new newsletters_woocommerce();
		register_activation_hook(__FILE__, array($newsletters_woocommerce, 'activation_hook'));
		
		// WordPress hooks
		add_action('init', array($newsletters_woocommerce, 'init_textdomain'), 10, 1);
		add_action('after_plugin_row_' . $plugin, array($newsletters_woocommerce, 'after_plugin_row'), 10, 2);
		add_action('install_plugins_pre_plugin-information', array($newsletters_woocommerce, 'display_changelog'), 10, 1);
		add_filter('transient_update_plugins', array($newsletters_woocommerce, 'check_update'), 10, 1);
		add_filter('site_transient_update_plugins', array($newsletters_woocommerce, 'check_update'), 10, 1);
		add_filter('plugin_action_links', array($newsletters_woocommerce, 'plugin_action_links'), 10, 4);
		
		// Newsletter plugin hooks
		add_action('wpml_metaboxes_extensions_settings', array($newsletters_woocommerce, 'metaboxes_extensions_settings'), 10, 1);
		add_action('wpml_contacts_before_register_button', array($newsletters_woocommerce, 'contacts_before_register_button'), 10, 2);
		add_action('wpml_shipping_after_global', array($newsletters_woocommerce, 'shipping_after_global'), 10, 2);
		add_action('wpml_billing_after_global', array($newsletters_woocommerce, 'billing_after_global'), 10, 2);
		add_filter('wpml_extensions_list', array($newsletters_woocommerce, 'extensions_list'), 10, 1);
		add_action('wpml_extensions_settings_saved', array($newsletters_woocommerce, 'newsletters_extensions_settings_saved'), 10, 1);
		
		// WooCommerce plugin hooks
		add_action('woocommerce_checkout_after_customer_details', array($newsletters_woocommerce, 'woo_checkout_after_customer_details'), 10, 1);
		add_action('woocommerce_after_checkout_validation', array($newsletters_woocommerce, 'woo_checkout_validation'), 10, 1);
	}
}

?>